@@ -98,7 +98,7 @@ func TestGetWithFallback(t *testing.T) {
 			t.Parallel()
 
 			value, err := GetWithFallback(test.groups...)
-			if len(test.expected.error) > 0 {
+			if test.expected.error != "" {
 				assert.EqualError(t, err, test.expected.error)
 			} else {
 				require.NoError(t, err)
