@@ -9,7 +9,6 @@ import (
 
 	"github.com/go-acme/lego/v4/challenge/dns01"
 	"github.com/go-acme/lego/v4/platform/config/env"
-	"github.com/miekg/dns"
 	"github.com/nrdcg/bunny-go"
 )
 
@@ -94,7 +93,7 @@ func (d *DNSProvider) Present(domain, token, keyAuth string) error {
 
 	authZone, err := getZone(info.EffectiveFQDN)
 	if err != nil {
-		return fmt.Errorf("bunny: failed to find zone: fqdn=%s: %w", info.EffectiveFQDN, err)
+		return fmt.Errorf("bunny: could not find zone for domain %q: %w", domain, err)
 	}
 
 	ctx := context.Background()
@@ -129,7 +128,7 @@ func (d *DNSProvider) CleanUp(domain, token, keyAuth string) error {
 
 	authZone, err := getZone(info.EffectiveFQDN)
 	if err != nil {
-		return fmt.Errorf("bunny:  failed to find zone: fqdn=%s: %w", info.EffectiveFQDN, err)
+		return fmt.Errorf("bunny: could not find zone for domain %q: %w", domain, err)
 	}
 
 	ctx := context.Background()
@@ -191,30 +190,11 @@ func getZone(fqdn string) (string, error) {
 		return "", err
 	}
 
-	zone, _, err := splitDomain(dns01.UnFqdn(authZone))
-	if err != nil {
-		return "", err
-	}
+	zone := dns01.UnFqdn(authZone)
 
 	return zone, nil
 }
 
-func splitDomain(full string) (string, string, error) {
-	split := dns.Split(full)
-	if len(split) < 2 {
-		return "", "", fmt.Errorf("unsupported domain: %s", full)
-	}
-
-	if len(split) == 2 {
-		return full, "", nil
-	}
-
-	domain := full[split[len(split)-2]:]
-	subDomain := full[:split[len(split)-2]-1]
-
-	return domain, subDomain, nil
-}
-
 func pointer[T string | int | int32 | int64](v T) *T { return &v }
 
 func deref[T string | int | int32 | int64](v *T) T {
